@@ -268,7 +268,7 @@ def count3MotifsSparse(G : nx.Graph,
     Both follow using a double counting principle.
     
     Warning: The input graph must not contain self loops. Check using 
-    ``G.nodes_with_selfloops()``.
+    :py:meth:`networkx.nodes_with_selfloops`.
     
     See also :py:meth:`sma.count3Motifs`.
     
@@ -280,7 +280,7 @@ def count3MotifsSparse(G : nx.Graph,
     """
     result = {key : 0 for key in sma.MOTIF3_NAMES}
     
-    H = G.subgraph(filter(lambda x : G.node[x]['sesType'] == level0 or G.node[x]['sesType'] == level1, G.nodes))
+    H = G.subgraph(filter(lambda x : G.nodes[x]['sesType'] == level0 or G.nodes[x]['sesType'] == level1, G.nodes))
     data = H.nodes(data=True)
     
     edges_count11 = 0
@@ -396,7 +396,7 @@ def count4MotifsSparse(G : nx.Graph,
     """
     result = {key : 0 for key in sma.MOTIF4_NAMES}
     
-    H = G.subgraph(filter(lambda x : G.node[x]['sesType'] == level0 or G.node[x]['sesType'] == level1, G.nodes))
+    H = G.subgraph(filter(lambda x : G.nodes[x]['sesType'] == level0 or G.nodes[x]['sesType'] == level1, G.nodes))
     data = H.nodes(data=True)
     
     edges_count00 = 0
@@ -483,10 +483,10 @@ def count121MotifsSparse(G : nx.Graph,
     result = {k : 0 for k in classificator.names}
     for lower in sma.sesSubgraph(G, level2):
         if optimize_top_adjacent:
-            top = filter(lambda x: G.node[x]['sesType'] == level0, G[lower])
+            top = filter(lambda x: G.nodes[x]['sesType'] == level0, G[lower])
         else:
             top = sma.sesSubgraph(G, level0)
-        middle = filter(lambda x: G.node[x]['sesType'] == level1, G[lower])
+        middle = filter(lambda x: G.nodes[x]['sesType'] == level1, G[lower])
         for a, (b,c) in itertools.product(top,itertools.combinations(middle, 2)):
             cl = classificator((a, b, c, lower))
             result[cl] +=1
@@ -798,7 +798,7 @@ def sesSubgraph(G : nx.Graph, sesType : int, source = None) -> filter:
     """
     if source == None:
         source = G.nodes
-    return filter(lambda x : G.node[x]['sesType'] == sesType, source)
+    return filter(lambda x : G.nodes[x]['sesType'] == sesType, source)
 
 # Simple properties
 
